# -*- coding: utf-8 -*-
"""
Created on Sat Oct 23 04:36:47 2019

Easy logging, timing and email notifications of code execution.

@author: tommy
"""

from .logger import logger, log, lg
from .notify import notify